@@ -17,7 +17,7 @@ class Settings(BaseSettings):
 
             'AWS_REGION': {'env': 'AWS_REGION'},
             'AWS_SNS_KEY': {'env': 'AWS_SNS_KEY'},
-            'AWS_SNS__SECRET': {'env': 'AWS_SNS__SECRET'},
+            'AWS_SNS_SECRET': {'env': 'AWS_SNS_SECRET'},
             'AWS_SNS_PATH': {'env': 'AWS_SNS_PATH'},
         }
 
